import Vue, {VueConstructor} from 'vue'

interface MesOpt {
  duration?: number,
  message?: string,
  msec?: number,   //显示时长
  position?: 'top' | 'center' | 'bottom', //上下方向 top|center|bottom(默认)
  align?: 'right' | 'left' | 'center',  //左右方向 right|left|center(默认)
  width?: number, //固定大小
  btns?: {
    name: string,
    click?: () => void,
    icon?: string,
    type?: "error" | 'primary' | 'info' | 'warning',//按钮样式，同ici-button
    key?: '' //键盘捷键
  }[], //按钮
  showClose?: boolean, //是否显示关闭按钮
}


interface RightMenu {
  name: string,
  rightName?: string
  icon?: string,
  colorIcon?: string //直接使用彩色的icon,iconColor将失败
  iconColor?: string,
  topLine?: boolean //顶部画线
  bottomLine?: boolean, //底部画分隔线
  key?: string, //键盘快捷键
  disabled?: boolean,

  click(): void,

  btns?: {
    html?: string
    icon?: string,
    iconColor: string,
    click(): void,
  }[],
  children?: Omit<RightMenu, 'btns' | 'children'>,
}

interface RightMenuComp {
  component: Vue.Component //当有传入组件 属性name、rightName、key、disabled、click将失效
  props?: { [key: string]: any } //要传入component的props
  icon?: string,
  iconColor?: string,
  topLine?: boolean //顶部画线
  bottomLine?: boolean, //底部画分隔线
}

declare const IciUi: {
  install: (Vue: VueConstructor, options: { locale: any, i18n: any, size: string, store: any }) => void;
};


export declare const iciButton: Vue.Component,
  iciMultipleField: Vue.Component,
  iciRadioField: Vue.Component,
  iciInput: Vue.Component,
  iciInputGroup: Vue.Component,
  iciPopup: Vue.Component,
  iciModal: Vue.Component,
  iciSearch: Vue.Component,
  iciHint: Vue.Component,
  iciHeader: Vue.Component,
  iciBgimg: Vue.Component,
  iciDrawer: Vue.Component,
  iciPoptip: Vue.Component,
  iciColorIcon: Vue.Component

interface IciPopup {
  title?: string,
  content: string,
  okText?: string,
  cancelText?: string,
  showClose?: boolean,
  titleClass?: string,
  bodyClass?: string,
  position?: 'fixed' | 'absolute',

  onOk?(): void,

  onCancel?(): void,
}


declare module 'vue/types/vue' {
  interface Vue {
    $popup: {
      confirm(opt: IciPopup): void
      close(): void,
    },
    $icitip: {
      close()
    },
  }
}

export default IciUi
